@@ -1,24 +1,11 @@
 /*
   This file is part of the KDE project
 
-  Copyright (C) 2002-2003 Daniel Molkentin <molkentin@kde.org>
-  Copyright (C) 2004-2006 Michael Brade <brade@kde.org>
-  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2002-2003 Daniel Molkentin <molkentin@kde.org>
+  SPDX-FileCopyrightText: 2004-2006 Michael Brade <brade@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "knotes_part.h"
@@ -89,7 +76,7 @@ KNotesPart::KNotesPart(QObject *parent)
     Akonadi::ControlGui::widgetNeedsAkonadi(widget());
 
     if (KNotesGlobalConfig::self()->autoCreateResourceOnStart()) {
-        NoteShared::LocalResourceCreator *creator = new NoteShared::LocalResourceCreator(this);
+        auto *creator = new NoteShared::LocalResourceCreator(this);
         creator->createIfMissing();
     }
 
@@ -347,7 +334,7 @@ void KNotesPart::printSelectedNotes(bool preview)
 
 void KNotesPart::newNote(const QString &name, const QString &text)
 {
-    NoteShared::CreateNewNoteJob *job = new NoteShared::CreateNewNoteJob(this, widget());
+    auto *job = new NoteShared::CreateNewNoteJob(this, widget());
     job->setRichText(KNotesGlobalConfig::self()->richText());
     job->setNote(name, text);
     job->start();
@@ -449,7 +436,7 @@ void KNotesPart::killSelectedNotes()
     QList<KNotesIconViewItem *> items;
     items.reserve(lst.count());
     for (QListWidgetItem *item : lst) {
-        KNotesIconViewItem *knivi = static_cast<KNotesIconViewItem *>(item);
+        auto *knivi = static_cast<KNotesIconViewItem *>(item);
         items.append(knivi);
     }
 
@@ -467,7 +454,7 @@ void KNotesPart::killSelectedNotes()
             }
         }
         if (!lst.isEmpty()) {
-            Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob(lst);
+            auto *job = new Akonadi::ItemDeleteJob(lst);
             connect(job, &Akonadi::ItemDeleteJob::result, this, &KNotesPart::slotDeleteNotesFinished);
         }
     }
@@ -485,7 +472,7 @@ void KNotesPart::popupRMB(QListWidgetItem *item, const QPoint &pos, const QPoint
 {
     Q_UNUSED(item);
 
-    QMenu *contextMenu = new QMenu(widget());
+    auto *contextMenu = new QMenu(widget());
     if (mNotesWidget->notesView()->itemAt(pos)) {
         contextMenu->addAction(mNewNote);
         const bool uniqueNoteSelected = (mNotesWidget->notesView()->selectedItems().count() == 1);
@@ -540,7 +527,7 @@ void KNotesPart::editNote(Akonadi::Item::Id id)
 
 void KNotesPart::editNote(QListWidgetItem *item)
 {
-    KNotesIconViewItem *knotesItem = static_cast<KNotesIconViewItem *>(item);
+    auto *knotesItem = static_cast<KNotesIconViewItem *>(item);
     QPointer<KNoteEditDialog> dlg = new KNoteEditDialog(knotesItem->readOnly(), widget());
     dlg->setTitle(knotesItem->realName());
     dlg->setText(knotesItem->description());
@@ -570,7 +557,7 @@ void KNotesPart::editNote()
 
 void KNotesPart::renameNote()
 {
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
 
     const QString oldName = knoteItem->realName();
     bool ok = false;
@@ -610,7 +597,7 @@ void KNotesPart::slotNotePreferences()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
     QPointer<KNoteSimpleConfigDialog> dialog = new KNoteSimpleConfigDialog(knoteItem->realName(), widget());
     Akonadi::Item item = knoteItem->item();
     dialog->load(item, knoteItem->isRichText());
@@ -621,7 +608,7 @@ void KNotesPart::slotNotePreferences()
         KMime::Message::Ptr message = item.payload<KMime::Message::Ptr>();
         message->contentType(true)->setMimeType(isRichText ? "text/html" : "text/plain");
         message->assemble();
-        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(item);
+        auto *job = new Akonadi::ItemModifyJob(item);
         connect(job, &Akonadi::ItemModifyJob::result, this, &KNotesPart::slotNoteSaved);
     }
     delete dialog;
@@ -650,7 +637,7 @@ void KNotesPart::slotMail()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
     NoteShared::NoteUtils noteUtils;
     noteUtils.sendToMail(widget(), knoteItem->realName(), knoteItem->description());
 }
@@ -660,7 +647,7 @@ void KNotesPart::slotSendToNetwork()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
     NoteShared::NoteUtils noteUtils;
     noteUtils.sendToNetwork(widget(), knoteItem->realName(), knoteItem->description());
 }
@@ -684,7 +671,7 @@ void KNotesPart::slotSetAlarm()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
     QPointer<NoteShared::NoteAlarmDialog> dlg = new NoteShared::NoteAlarmDialog(knoteItem->realName(), widget());
     Akonadi::Item item = knoteItem->item();
     if (item.hasAttribute<NoteShared::NoteAlarmAttribute>()) {
@@ -694,7 +681,7 @@ void KNotesPart::slotSetAlarm()
         bool needToModify = true;
         QDateTime dateTime = dlg->alarm();
         if (dateTime.isValid()) {
-            NoteShared::NoteAlarmAttribute *attribute
+            auto *attribute
                 = item.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
             attribute->setDateTime(dateTime);
         } else {
@@ -705,7 +692,7 @@ void KNotesPart::slotSetAlarm()
             }
         }
         if (needToModify) {
-            Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(item);
+            auto *job = new Akonadi::ItemModifyJob(item);
             connect(job, &Akonadi::ItemModifyJob::result, this, &KNotesPart::slotNoteSaved);
         }
     }
@@ -731,7 +718,7 @@ void KNotesPart::slotSaveAs()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
 
     QStringList filters;
     if (knoteItem->isRichText()) {
@@ -779,7 +766,7 @@ void KNotesPart::slotUpdateReadOnly()
     if (!item) {
         return;
     }
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(item);
+    auto *knoteItem = static_cast<KNotesIconViewItem *>(item);
 
     const bool readOnly = mReadOnly->isChecked();
 
@@ -837,7 +824,7 @@ void KNotesPart::slotCollectionChanged(const Akonadi::Collection &col, const QSe
 
 void KNotesPart::fetchNotesFromCollection(const Akonadi::Collection &col)
 {
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(col);
+    auto *job = new Akonadi::ItemFetchJob(col);
     job->fetchScope().fetchFullPayload(true);
     job->fetchScope().fetchAttribute<NoteShared::NoteLockAttribute>();
     job->fetchScope().fetchAttribute<NoteShared::NoteDisplayAttribute>();
@@ -853,7 +840,7 @@ void KNotesPart::slotItemFetchFinished(KJob *job)
         return;
     }
 
-    Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
 
     const Akonadi::Item::List items = fetchJob->items();
     for (const Akonadi::Item &item : items) {
